@@ -4,7 +4,7 @@ use strict;
 use Moose::Role;
 use namespace::autoclean;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 
 around execute => sub {
@@ -16,6 +16,7 @@ around execute => sub {
     unless ($view) {
         $view = $c->config->{default_view};
     }
+    
     my $renderer = sprintf "View::%s", $view;
     $c->log->debug($renderer);
 
@@ -43,14 +44,25 @@ Catalyst::ActionRole::Renderer - Rendering views for Catalyst action
 
   BEGIN { extends 'Catalyst::Controller'; }
 
-  sub lookup :GET Args(1) :Does(Renderer) :View(TT) {
+  sub lookup :Local :Does(Renderer) :View(TT) {
       my ( $self, $c ) = @_;
+      $c->stash->{template} = 'helloworld.tt';
   }
 
 
 =head1 DESCRIPTION
 
-Catalyst::ActionRole::Renderer is rendering views for Catalyst action
+Catalyst::ActionRole::Renderer is rendering views for Catalyst action.
+
+capable of declaratively rendering views.
+
+=over 2
+
+=item No C<$c.forward> 
+
+=item No C<sub end : ActionClass('RenderView') {}> 
+
+=back
 
 
 =head1 SEE ALSO
@@ -58,9 +70,9 @@ Catalyst::ActionRole::Renderer is rendering views for Catalyst action
 
 =over 2
 
-=item L<Catalyst::View>
+=item L<Catalyst::Controller>
 
-=item L<Catalyst::ActionRole>
+=item L<Catalyst::View>
 
 =back
 
